==> v1.0.tar.gz: codeigniter4cms/app/Views/addProductForm.php <==
<?= $this->extend('layout') ?>
<?= $this->section('content') ?>


<div class ="flex2">
	<div class ="content">
		
		   
		
			<div class="d-flex justify-content-center">
            
           
            <?= form_open_multipart('addProduct'); ?>
			
			<div class ="form-group">
			 <h11>Form to add a product</h11>
            
			</div>
			
			<div class="form-group"> 
			<label for="title">Brief Product Description(title of product)</label>
			 <input type="input" name="title" id ="title" class="form-control"/><br />
			 </div>
    
            <div class="form-group"> 
			<label for="category">Select category For product</label>	
			<select id="category" name="category">
			<option value="FToner">Toner n Cleanser</option>
			<option value="FExfoliate">Face Exfoliate</option>
			<option value="FMask">Face Mask</option>
			<option value="BLotion">Body Lotion</option>
			<option value="HTreatment">Hair Treatment Serum</option>
			<option value="Baby"></option>
			<option value="Accessory"></option>
			</select> 
			</div><!-- end form group for select-->
			  
	         <div class = "form-group">
	          <label for="price">Price Numbers only</label> 
	          <input type="input" name="price" id ="price" class="form-control"/><br />
	         </div>
			   
	    
	         <div class="form-group"> 
			 <label for="info">Full Product Details </label> 
			 <textarea class="form-control" id ="prodInfo" rows="3" cols ="24" name ="info" required ="true"  ></textarea>
			 </div>
			 
	    
	    
	    
				<div class="form-group"> 
			    <label for="image">Use browse button below to navigate to image</label>
			    <br><br>
			    <input type="file" name="productImage" size="20" id="productFile" required ="true"/>
			    </div>
	    
	    
	    
			    <div class="form-group"> 
			   <input type="submit" class ="btn-success" value="submit" />
			   </div>
                           
			   
			   <div class="form-group"> 
			 <h1 style ="color:red";>  <?php echo $info ;?></h1>
			   </div>
			   
			   
			   
		   <?php echo form_close();?>

	</div><!--end div class flex d-->
	
	
	</div><!-- content end-->
</div><!-- flex end-->
<?= $this->endSection() ?>

==> 1.1.tar.gz: codeigniter4cms/app/Views/addProductForm.php <==
<?= $this->extend('layout') ?>
<?= $this->section('content') ?>


<div class ="flex2">
	<div class ="content">
		
		   
		
			<div class="d-flex justify-content-center">
            
           
            <?= form_open_multipart('addProduct'); ?>
			<?= csrf_field() ?>
			<div class ="form-group">
			 <h11>Form to add a product</h11>
            
			</div>
			
			<div class="form-group"> 
			<label for="title">Brief Product Description(title of product)</label>
			 <input type="input" name="title" id ="title" class="form-control"/><br />
			 </div>
    
            <div class="form-group"> 
			<label for="category">Select category For product</label>	
			<select id="category" name="category">
			
			<option value="FMens">Mens</option>
			<option value="FLadies">Ladies</option>
						<option value="FAccessories">Accessories</option>
			
			
			</select> 
			</div><!-- end form group for select-->
			  
	         <div class = "form-group">
	          <label for="price">Price Numbers only</label> 
	          <input type="input" name="price" id ="price" class="form-control"/><br />
	         </div>
			   
	    
	         <div class="form-group"> 
			 <label for="info">Full Product Details </label> 
			 <textarea class="form-control" id ="prodInfo" rows="3" cols ="24" name ="info" required ="true"  ></textarea>
			 </div>
			 
	    
	    
	    
				<div class="form-group"> 
			    <label for="image">Use browse button below to navigate to image</label>
			    <br><br>
			    <input type="file" name="productImage" size="20" id="productFile" required ="true"/>
			    </div>
	    
	    
	    
			    <div class="form-group"> 
			   <input type="submit" class ="btn-success" value="submit" />
			   </div>
                           
			   
			   <div class="form-group"> 
			 <h1 style ="color:red";>  <?php echo $info ;?></h1>
			   </div>
			   
			   
			   
		   <?php echo form_close();?>

	</div><!--end div class flex d-->
	
	
	</div><!-- content end-->
</div><!-- flex end-->
<?= $this->endSection() ?>
